@@ -239,7 +239,13 @@ function auto_detect(info_str) {
             if (lowermodel.startsWith("z2_")      || lowerdescname.startsWith("z2_"))     exact_match_by_name("B&W", "Z2"); 
             if (lowermodel.startsWith("t7_")      || lowerdescname.startsWith("t7_"))     exact_match_by_name("B&W", "T7");
             if (lowermodel.startsWith("appletv")  || lowerdescname.startsWith("appletv")) exact_match_by_name("Apple", "Apple TV");
-            if (lowermodel.startsWith("airport4") || lowerdescname.startsWith("airport4")) exact_match_by_name("Apple", "Airport Express");
+            if (lowermodel.startsWith("airport4") || lowerdescname.startsWith("airport4")) exact_match_by_name("apple", "airport express");
+            if (lowermodel.startsWith("audioaccessory6,1|audioaccessory6,1"))              exact_match_by_name("Apple", "HomePod (Stereo Pair)");
+            if (lowermodel.startsWith("audioaccessory6,1|appletv"))                        exact_match_by_name("Apple", "Apple TV / HomePod");
+            if (lowermodel.startsWith("audioaccessory6,1"))                                exact_match_by_name("Apple", "HomePod");
+            if (lowermodel.startsWith("audioaccessory5,1|audioaccessory5,1"))              exact_match_by_name("Apple", "HomePod mini (Stereo Pair)");
+            if (lowermodel.startsWith("audioaccessory5,1|appletv"))                        exact_match_by_name("Apple", "Apple TV / HomePod mini");  
+            if (lowermodel.startsWith("audioaccessory5,1"))                                exact_match_by_name("Apple", "HomePod mini");  
             if (lowerdescname.startsWith("denon")){
                 var tempVendor = "Denon";
                 var tempDevice = model;
@@ -443,4 +449,4 @@ if (!Array.prototype.includes) {
       return false;
     }
   });
-}
\ No newline at end of file
+}
